@@ -27,29 +27,48 @@ class Histogram_GUI(QtWidgets.QWidget):
 
         self.plot_hist = QtWidgets.QPushButton("plot_histogram")
         self.plot_hist.clicked.connect(self.do_hist)
+        self.plot_hist.setFixedWidth(150)
 
         self.le_lower_contrast_trim = QtWidgets.QLineEdit()
         self.le_lower_contrast_trim.setPlaceholderText("lower_limitation")
         self.le_lower_contrast_trim_label = QtWidgets.QLabel("lower limitation (Contrast):")
+        self.le_lower_contrast_trim.setFixedWidth(150)
 
         self.le_upper_contrast_trim = QtWidgets.QLineEdit()
         self.le_upper_contrast_trim.setPlaceholderText("upper_limitation")
         self.le_upper_contrast_trim_label = QtWidgets.QLabel("upper limitation (Contrast):")
+        self.le_upper_contrast_trim.setFixedWidth(150)
 
         self.le_MaxGMM_mode = QtWidgets.QLineEdit()
         self.le_MaxGMM_mode.setPlaceholderText("max_n_components for GMM")
         self.le_MaxGMM_mode_label = QtWidgets.QLabel("max n_components:")
+        self.le_MaxGMM_mode.setFixedWidth(150)
 
         self.le_hist_bin = QtWidgets.QLineEdit()
         self.le_hist_bin.setPlaceholderText("#bins")
-        self.le_hist_bin_label = QtWidgets.QLabel("bins:")
+        self.le_hist_bin_label = QtWidgets.QLabel("Histogram bins:")
+        self.le_hist_bin.setFixedWidth(150)
 
         self.min_peak_width = QtWidgets.QLineEdit()
         self.min_peak_width.setPlaceholderText("Min Peak Width")
         self.min_peak_width_label = QtWidgets.QLabel("Min Peak Width:")
+        self.min_peak_width.setFixedWidth(150)
+
+        self.axis_limit = QtWidgets.QLineEdit()
+        self.axis_limit.setPlaceholderText("scale * upper_limitation")
+        self.le_axis_limit = QtWidgets.QLabel("Scale x-axis:")
+        self.axis_limit.setFixedWidth(150)
+
+        self.GMM_visualization_mode_group = QtWidgets.QButtonGroup()
+        self.radio_mode_1 = QtWidgets.QRadioButton("Separate mixture")
+        self.radio_mode_2 = QtWidgets.QRadioButton("Superposition mixture")
+        self.GMM_visualization_mode_group.addButton(self.radio_mode_1)
+        self.GMM_visualization_mode_group.addButton(self.radio_mode_2)
 
         self.grid = QtWidgets.QGridLayout()
         self.grid.addWidget(self.createFirstExclusiveGroup(), 0, 0)
+        self.grid.addWidget(self.createSecondExclusiveGroup(), 1, 0)
+        self.grid.addWidget(self.plot_hist, 2, 0)
 
         self.setLayout(self.grid)
 
@@ -57,27 +76,40 @@ class Histogram_GUI(QtWidgets.QWidget):
         print('Destructor called, Employee deleted.')
 
     def createFirstExclusiveGroup(self):
-        self.checkbox_GMM_FIT = QtWidgets.QCheckBox("Histogram and Gaussian mixture models (GMM)", self)
 
-        self.groupBox_hist = QtWidgets.QGroupBox("Histogram and Gaussian mixture models (GMM)")
+        self.groupBox_hist = QtWidgets.QGroupBox("Histogram setting")
 
         self.grid3 = QtWidgets.QGridLayout()
-        self.grid3.addWidget(self.min_peak_width_label, 0, 0)
-        self.grid3.addWidget(self.min_peak_width, 0, 1)
-        self.grid3.addWidget(self.le_lower_contrast_trim_label, 1, 0)
-        self.grid3.addWidget(self.le_lower_contrast_trim, 1, 1)
-        self.grid3.addWidget(self.le_upper_contrast_trim_label, 2, 0)
-        self.grid3.addWidget(self.le_upper_contrast_trim, 2, 1)
-        self.grid3.addWidget(self.le_MaxGMM_mode_label, 3, 0)
-        self.grid3.addWidget(self.le_MaxGMM_mode, 3, 1)
-        self.grid3.addWidget(self.checkbox_GMM_FIT, 3, 2)
-        self.grid3.addWidget(self.le_hist_bin_label, 4, 0)
-        self.grid3.addWidget(self.le_hist_bin, 4, 1)
-        self.grid3.addWidget(self.plot_hist, 5, 0)
+
+        self.grid3.addWidget(self.le_lower_contrast_trim_label, 0, 0)
+        self.grid3.addWidget(self.le_lower_contrast_trim, 1, 0)
+        self.grid3.addWidget(self.le_upper_contrast_trim_label, 0, 1)
+        self.grid3.addWidget(self.le_upper_contrast_trim, 1, 1)
+        self.grid3.addWidget(self.min_peak_width_label, 2, 0)
+        self.grid3.addWidget(self.min_peak_width, 3, 0)
+        self.grid3.addWidget(self.le_hist_bin_label, 2, 1)
+        self.grid3.addWidget(self.le_hist_bin, 3, 1)
+        self.grid3.addWidget(self.le_axis_limit, 4, 0)
+        self.grid3.addWidget(self.axis_limit, 5, 0)
 
         self.groupBox_hist.setLayout(self.grid3)
         return self.groupBox_hist
 
+    def createSecondExclusiveGroup(self):
+
+        self.groupBox_gmm = QtWidgets.QGroupBox("Gaussian mixture models (GMM):")
+        self.groupBox_gmm.setCheckable(True)
+        self.groupBox_gmm.setChecked(False)
+
+        self.grid4 = QtWidgets.QGridLayout()
+        self.grid4.addWidget(self.le_MaxGMM_mode_label, 0, 0)
+        self.grid4.addWidget(self.le_MaxGMM_mode, 0, 1)
+        self.grid4.addWidget(self.radio_mode_1, 0, 2)
+        self.grid4.addWidget(self.radio_mode_2, 0, 3)
+
+        self.groupBox_gmm.setLayout(self.grid4)
+        return self.groupBox_gmm
+
     def do_hist(self):
         self.step_limit = 1e-6
 
